@@ -4,7 +4,8 @@ from dataclasses import field
 from pathlib import Path
 from typing import Union
 
-__version__ = "1.3.4"
+__version__ = "1.4.0"
+metadata_dataclasses_json = {"dataclasses_json": {"mm_field": Path}}
 
 
 def create_file_path_field(path: Union[Path, str], path_is_absolute: bool = False) -> Path:
@@ -16,7 +17,7 @@ def create_file_path_field(path: Union[Path, str], path_is_absolute: bool = Fals
     """
     default_path = build_path(path, path_is_absolute)
     # noinspection Mypy
-    field_instance: Path = field(default=default_path, init=False, metadata={"dataclasses_json": {"mm_field": Path}})
+    field_instance: Path = field(default=default_path, init=False, metadata=metadata_dataclasses_json)
     return field_instance
 
 
